@@ -12,6 +12,40 @@ from ..services.clients import DatasetDocClient
 from ..jupyterextensions.authextension import AuthClient, AuthError
 
 
+def extract_doc(df):
+    if not isinstance(df, DataFrame):
+        raise UsageError("The variable '{}' is not a pyspark DataFrame".format(df))
+    if hasattr(df, 'doc'):
+        return map_doc_output(df.doc)
+    else:
+        return None
+
+
+def map_doc_output(doc_json):
+    def filter_ignored_variables(variable):
+        # Todo - use an ignore field instead
+        return variable['description'] is not None and variable['description'] != ''
+
+    def map_variable(variable):
+        return dict(map(map_variable_field, variable.items()))
+
+    def map_variable_field(variable_field):
+        if type(variable_field[1]) is dict:
+            return variable_field[0], strip_content(variable_field[1])
+        else:
+            return variable_field
+
+    def strip_content(field):
+        names = ('candidates', 'enums')
+        return dict(filter(lambda f: f[0] not in names, field.items()))
+
+    return {
+        'name': doc_json['name'],
+        'description': doc_json['description'],
+        'unitType': strip_content(doc_json['unitType']),
+        'instanceVariables': list(map(map_variable, filter(filter_ignored_variables, doc_json['instanceVariables'])))}
+
+
 @magics_class
 class DaplaDocumentationMagics(Magics):
     """Magics related to documentation management (loading, saving, editing, ...)."""
@@ -41,15 +75,16 @@ class DaplaDocumentationMagics(Magics):
 
     @line_magic
     def document(self, line):
-        """This line magic assists creating documentation metadata for a given variable name. The variable must be a Spark DataFrame.
+        """This line magic assists creating documentation metadata for a given variable_name. The variable_name must be
+        resolved to a Spark DataFrame.
 
         Usage:\\
-          %document [options] variablename
+          %document [options] variable_name
 
         Options:
 
-            -f <filename>: specify a file where the documentation is stored
-            --nofile : Documentation is not stored to file
+            --nofile  : Documentation is not stored to file
+            -f <path> : Specifies a file path where the documentation is stored
         """
 
         opts, args = self.parse_options(line, 'f:', 'nofile')
@@ -68,17 +103,22 @@ class DaplaDocumentationMagics(Magics):
             raise UsageError("The variable '{}' is not a pyspark DataFrame".format(args))
 
         if fname is None and use_file_storage:
-            fname = self.ensure_valid_filename(
-                self.shell.ev('input("Enter filename where the documentation should be stored")'))
+            fname = self.shell.ev('input("Enter filename where the documentation should be stored '
+                                  '(leave blank for no file)")')
             # Update the user input for future use
-            contents = "%document -f {} {}".format(fname, line)
+            if fname == '':
+                use_file_storage = False
+                contents = "%document --nofile {}".format(line)
+            else:
+                contents = "%document -f {} {}".format(self.ensure_valid_filename(fname), line)
             self.shell.set_next_input(contents, replace=True)
         elif use_file_storage:
             fname = self.ensure_valid_filename(fname)
 
         if hasattr(ds, 'doc') and ds.doc is not None:
             try:
-                ans = self.shell.ask_yes_no("Do you wish to overwrite existing documentation?", default='n')
+                ans = self.shell.ask_yes_no("The dataset '{}' has already been documented. "
+                                            "Do you want to proceed?".format(args), default='n')
             except StdinNotImplementedError:
                 # skip execution if this note is run in batch mode
                 ans = False
@@ -134,10 +174,10 @@ class DaplaDocumentationMagics(Magics):
                 display='flex',
                 flex_flow='column',
                 align_items='stretch',
-                width='50%'
+                width='70%'
             )))
 
-        accordion = widgets.Accordion(children=variable_forms)
+        accordion = widgets.Accordion(children=variable_forms, selected_index=None)
 
         for i in range(len(variable_forms)):
             accordion.set_title(i, variable_titles[i])
@@ -152,12 +192,12 @@ class DaplaDocumentationMagics(Magics):
                 display='flex',
                 flex_flow='column',
                 align_items='stretch',
-                width='50%'
+                width='70%'
             )
         )
 
-        display_objs = (widgets.HTML("<b>Dataset metadata</b>"), dataset_doc,
-                        widgets.HTML("<b>Instance variables</b>"), accordion)
+        display_objs = (widgets.HTML('<b style="font-size:14px">Dataset metadata</b>'), dataset_doc,
+                        widgets.HTML('<b style="font-size:14px">Instance variables</b>'), accordion)
 
         def on_button_clicked(b):
             with open(fname, 'w', encoding="utf-8") as f:
@@ -167,9 +207,9 @@ class DaplaDocumentationMagics(Magics):
             btn = widgets.Button(description='Save to file', icon='file-code')
             btn.on_click(on_button_clicked)
             out = widgets.Output()
-            self.display(*display_objs, btn, out)
+            self.display(widgets.VBox([*display_objs, btn, out]))
         else:
-            self.display(*display_objs)
+            self.display(widgets.VBox(display_objs))
 
     def create_widget(self, binding, key):
         if isinstance(binding[key], str):
