@@ -1,4 +1,4 @@
-from .clients import DataAccessClient, DataAccessError, MetadataPublisherClient, CatalogClient, DatasetDocClient
+from .clients import DataAccessClient, DataAccessError, MetadataPublisherClient, CatalogClient
 from .gcs import GCSFileSystem
 from pathlib import Path
 import pyarrow.parquet
@@ -18,7 +18,6 @@ class DataSourceWriter:
             metadata_publisher_project_id=None,
             metadata_publisher_topic_name=None,
             catalog_url=None,
-            _dataset_doc_client_url=None
     ):
         """
         Args:
@@ -35,7 +34,6 @@ class DataSourceWriter:
             user_token_provider, metadata_publisher_url,
             metadata_publisher_project_id, metadata_publisher_topic_name)
         self._catalog_client = CatalogClient(user_token_provider, catalog_url)
-        self._dataset_doc_client = DatasetDocClient(user_token_provider, _dataset_doc_client_url)
 
     @staticmethod
     def _current_milli_time():
